@@ -221,33 +221,47 @@ string_replace (const char *input,
 }
 
 /* This function wraps g_date_time_format, replacing colon with the ratio
- * character as it looks visually better in time strings.
+ * character and underscores with en-space as it looks visually better
+ * in time strings.
  */
 static char *
 date_time_format (GDateTime *datetime,
                   const char *format)
 {
-	char *format_with_colon;
+	char *replaced_format;
 	char *ret;
-	char *tmp;
+	char *no_ratio, *no_enspace;
 	gboolean is_utf8;
 
 	is_utf8 = g_get_charset (NULL);
 
-	/* First, replace ratio with plain colon before passing it to
+	/* First, replace ratio with plain colon */
+	no_ratio = string_replace (format, "∶", ":");
+	/* Then do the same with en-space and underscore before passing it to
 	 * g_date_time_format.  */
-	tmp = string_replace (format, "∶", ":");
-	format_with_colon = g_date_time_format (datetime, tmp);
-	g_free (tmp);
+	no_enspace = string_replace (no_ratio, " ", "_");
+	replaced_format = g_date_time_format (datetime, no_enspace);
 
-	/* Then, after formatting, replace the plain colon with ratio, and
-	 * prepend it with an LTR marker to force direction. */
-	if (is_utf8)
-		ret = string_replace (format_with_colon, ":", "\xE2\x80\x8E∶");
-	else
-		ret = g_strdup (format_with_colon);
+	g_free (no_ratio);
+	g_free (no_enspace);
 
-	g_free (format_with_colon);
+	if (is_utf8) {
+		char *tmp;
+		/* Then, after formatting, replace the plain colon with ratio,
+		 * and prepend it with an LTR marker to force direction. */
+		tmp = string_replace (replaced_format, ":", "\xE2\x80\x8E∶");
+
+		/* Finally, replace double spaces with a single en-space.*/
+		ret = string_replace (tmp, "_", " ");
+
+		g_free (tmp);
+	} else {
+		/* Colon instead of ratio is already fine, but replace the
+		 * underscore with double spaces instead of en-space */
+		ret = string_replace (replaced_format, "_", "  ");
+	}
+
+	g_free (replaced_format);
 	return ret;
 }
 
@@ -269,10 +283,18 @@ gnome_wall_clock_string_for_datetime (GnomeWallClock      *self,
 
 	if (clock_format == G_DESKTOP_CLOCK_FORMAT_24H) {
 		if (show_full_date) {
-			/* Translators: This is the time format with full date used
-			   in 24-hour mode. */
-			format_string = show_seconds ? _("%a %b %e, %R:%S")
-				: _("%a %b %e, %R");
+			if (show_weekday)
+				/* Translators: This is the time format with full date
+				   plus day used in 24-hour mode. Please keep the under-
+				   score to separate the date from the time. */
+				format_string = show_seconds ? _("%a %b %-e_%R:%S")
+					: _("%a %b %-e_%R");
+			else
+				/* Translators: This is the time format with full date
+				   used in 24-hour mode. Please keep the underscore to
+				   separate the date from the time. */
+				format_string = show_seconds ? _("%b %-e_%R:%S")
+					: _("%b %-e_%R");
 		} else if (show_weekday) {
 			/* Translators: This is the time format with day used
 			   in 24-hour mode. */
@@ -285,10 +307,18 @@ gnome_wall_clock_string_for_datetime (GnomeWallClock      *self,
 		}
 	} else {
 		if (show_full_date) {
-			/* Translators: This is a time format with full date used
-			   for AM/PM. */
-			format_string = show_seconds ? _("%a %b %e, %l:%M:%S %p")
-				: _("%a %b %e, %l:%M %p");
+			if (show_weekday)
+				/* Translators: This is a time format with full date
+				   plus day used for AM/PM. Please keep the under-
+				   score to separate the date from the time. */
+				format_string = show_seconds ? _("%a %b %-e_%l:%M:%S %p")
+					: _("%a %b %-e_%l:%M %p");
+			else
+				/* Translators: This is a time format with full date
+				   used for AM/PM. Please keep the underscore to
+				   separate the date from the time. */
+				format_string = show_seconds ? _("%b %-e_%l:%M:%S %p")
+					: _("%b %-e_%l:%M %p");
 		} else if (show_weekday) {
 			/* Translators: This is a time format with day used
 			   for AM/PM. */
@@ -373,6 +403,7 @@ on_schema_change (GSettings *schema,
 {
 	if (g_strcmp0 (key, "clock-format") != 0 &&
 	    g_strcmp0 (key, "clock-show-seconds") != 0 &&
+	    g_strcmp0 (key, "clock-show-weekday") != 0 &&
 	    g_strcmp0 (key, "clock-show-date") != 0) {
 		return;
 	}
